@@ -752,7 +752,7 @@ def dataframe_to_xml(df, name, roffset, coffset, rows, cols, format):
                 kind = df.dtype.kind
             except AttributeError:
                 try:
-                    kind = df.dtypes[0].kind
+                    kind = df.dtypes.iloc[0].kind
                 except (IndexError, KeyError, AttributeError):
                     kind = 'O'
             format = array_default_format(kind)
