@@ -106,16 +106,23 @@ def is_tensorflow_contrib_ops_module(qname):
     return TENSORFLOW_CONTRIB_OPS_MODULE_PATTERN.match(qname)
 
 
+def is_debugpy_module(qname):
+    # Debugpy modules should not be processed
+    return DEBUGPY_PATTERN.match(qname)
+
+
 def is_skipped_module(path, f, qname):
     return (is_mac_skipped_module(path, f) or
             is_posix_skipped_module(path, f[:f.rindex('.')]) or
             'pynestkernel' in f or
-            is_tensorflow_contrib_ops_module(qname))
+            is_tensorflow_contrib_ops_module(qname) or
+            is_debugpy_module(qname))
 
 
 def is_module(d, root):
     return (os.path.exists(os.path.join(root, d, "__init__.py")) or
             os.path.exists(os.path.join(root, d, "__init__.pyc")) or
+            os.path.exists(os.path.join(root, d, "__init__.pyi")) or
             os.path.exists(os.path.join(root, d, "__init__.pyo")) or
             is_valid_implicit_namespace_package_name(d))
 
@@ -221,7 +228,7 @@ def skeleton_status(base_dir, mod_qname, mod_path, sdk_skeleton_state=None):
         used_version = version_to_tuple(used_version)
 
     used_bin_mtime = skeleton_meta.get('bin_mtime')
-    # state.json is normally passed for remote skeletons only. Since we don't have neither cache,
+    # state.json is normally passed for remote skeletons only. Since we have neither cache,
     # nor physical sdk skeletons there, we have to rely on binary modification time to detect
     # outdated skeletons.
     if mod_path and used_bin_mtime is not None and used_bin_mtime < file_modification_timestamp(mod_path):
@@ -366,7 +373,7 @@ def get_module_origin(mod_path, mod_qname):
         return None
 
     if is_test_mode():
-        return get_relative_path_by_qname(mod_path, mod_qname)
+        return get_portable_test_module_path(mod_path, mod_qname)
     return mod_path
 
 
@@ -468,8 +475,6 @@ class SkeletonGenerator(object):
         if not self.roots:
             return []
         # TODO Move to future InterpreterHandler
-        if IS_JAVA:  # jython can't have binary modules
-            return []
         paths = sorted_no_case(self.roots)
         for path in paths:
             for root, files in walk_python_path(path):
@@ -591,6 +596,11 @@ def imported_names_collected():
             imported_names.add(fullname)
             return None
 
+        # noinspection PyMethodMayBeStatic
+        def find_spec(self, fullname, path, target=None):
+            imported_names.add(fullname)
+            return None
+
     my_finder = MyFinder()
     sys.meta_path.insert(0, my_finder)
     try:
@@ -624,6 +634,8 @@ def generate_skeleton(name, mod_file_name, mod_cache_dir, output_dir):
     if redo_imports:
         initial_module_set = set(sys.modules)
         for m in list(sys.modules):
+            if not m.startswith(name):
+                continue
             # Python 2 puts dummy None entries in sys.modules for imports of
             # top-level modules made from inside packages unless absolute
             # imports are explicitly enabled.
